==> apache-druid-0.22.0-src.tar.gz: apache-druid-0.22.0-src/core/src/main/java/org/apache/druid/java/util/http/client/response/InputStreamFullResponseHolder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.java.util.http.client.response;

import org.apache.druid.java.util.http.client.io.AppendableByteArrayInputStream;
import org.jboss.netty.handler.codec.http.HttpResponse;
import org.jboss.netty.handler.codec.http.HttpResponseStatus;

import java.io.InputStream;

public class InputStreamFullResponseHolder extends FullResponseHolder<InputStream>
{
  private final AppendableByteArrayInputStream is;

  public InputStreamFullResponseHolder(
      HttpResponseStatus status,
      HttpResponse response
  )
  {
    super(status, response);
    is = new AppendableByteArrayInputStream();
  }

  public InputStreamFullResponseHolder addChunk(byte[] chunk)
  {
    is.add(chunk);
    return this;
  }

  @Override
  public InputStream getContent()
  {
    return is;
  }

  public void done()
  {
    is.done();
  }

  public void exceptionCaught(Throwable t)
  {
    is.exceptionCaught(t);
  }
}

==> apache-druid-25.0.0-src.tar.gz: apache-druid-25.0.0-src/core/src/main/java/org/apache/druid/java/util/http/client/response/InputStreamFullResponseHolder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.java.util.http.client.response;

import org.apache.druid.java.util.http.client.io.AppendableByteArrayInputStream;
import org.jboss.netty.handler.codec.http.HttpResponse;

import java.io.InputStream;

public class InputStreamFullResponseHolder extends FullResponseHolder<InputStream>
{
  private final AppendableByteArrayInputStream is;

  public InputStreamFullResponseHolder(HttpResponse response)
  {
    super(response);
    is = new AppendableByteArrayInputStream();
  }

  public InputStreamFullResponseHolder addChunk(byte[] chunk)
  {
    is.add(chunk);
    return this;
  }

  @Override
  public InputStream getContent()
  {
    return is;
  }

  public void done()
  {
    is.done();
  }

  public void exceptionCaught(Throwable t)
  {
    is.exceptionCaught(t);
  }
}
